@@ -11,6 +11,15 @@ _RDF_TYPE_CONTRACTED = ["a", "rdf:type"]
 _RDF_TYPE_URI = "<http://www.w3.org/1999/02/22-rdf-syntax-ns#type>"
 _BOOLEANS = ["true", "false"]
 _INI_BASE_URIS = ["/", "#"]
+_CLOSURES = [",", ";", "."]
+_S = 0
+_P = 1
+_O = 2
+
+_WAITING_FOR_SUBJ = 0
+_WAITING_FOR_PRED = 1
+_WAITING_FOR_OBJ = 2
+_NOT_WAITING = 4
 
 """
 TTL parser that yield triples (model objects) without loading the whole graph content in 
@@ -43,6 +52,7 @@ class BigTtlTriplesYielder(BaseTriplesYielder):
         self._base = None
 
         # To be used while parsing
+        self._state = _WAITING_FOR_SUBJ
         self._tmp_s = None
         self._tmp_p = None
         self._tmp_o = None
@@ -51,21 +61,33 @@ class BigTtlTriplesYielder(BaseTriplesYielder):
         self._triple_ready = False
 
     def yield_triples(self):
-        self._reset_count()
+        self._reset_parsing()
         for a_line in self._line_reader.read_lines():
-            self._process_line(a_line)
-            if self._triple_ready:
+            for a_triple in self._process_line_2(a_line):
                 self._triples_count += 1
                 yield (
-                    tune_subj(self._tmp_s,
+                    tune_subj(a_triple[_S],
                               raise_error_if_no_corners=False),
-                    tune_prop(self._tmp_p),
-                    tune_token(self._tmp_o,
+                    tune_prop(a_triple[_P],
+                              raise_error_if_no_corners=False),
+                    tune_token(a_triple[_O],
                                base_namespace=self._base,
                                allow_untyped_numbers=self._allow_untyped_numbers,
                                raise_error_if_no_corners=False)
                 )
-                self._triple_ready = False
+            # self._process_line(a_line)
+            # if self._triple_ready:
+            #     self._triples_count += 1
+            #     yield (
+            #         tune_subj(self._tmp_s,
+            #                   raise_error_if_no_corners=False),
+            #         tune_prop(self._tmp_p),
+            #         tune_token(self._tmp_o,
+            #                    base_namespace=self._base,
+            #                    allow_untyped_numbers=self._allow_untyped_numbers,
+            #                    raise_error_if_no_corners=False)
+            #     )
+            #     self._triple_ready = False
 
 
     def _clean_line(self, str_line):
@@ -95,8 +117,95 @@ class BigTtlTriplesYielder(BaseTriplesYielder):
         return str_line  # If this point is reached, it means that the potential comments
                          # are actual content of a string literal
 
+    def _process_line_2(self, str_line):
+        str_line = self._clean_line(str_line)
+        if str_line == "":
+            self._process_empty_line(str_line)
+        elif str_line.startswith("@prefix"):
+            self._process_prefix_line(str_line)
+        elif str_line.startswith("@base"):
+            self._process_base_line(str_line)
+        elif str_line.startswith("#"):
+            self._process_comment_line(str_line)
+        else:
+            for a_triple in self._process_line_with_potential_triples(str_line):
+                yield a_triple
+
+    def _process_line_with_potential_triples(self, a_line):
+        next_token, next_index = self._next_line_token(a_line, 0)
+        while next_token != None:
+            if next_token == ",":
+                yield self._current_triple()
+                self._state = _WAITING_FOR_OBJ
+            elif next_token == ";":
+                yield self._current_triple()
+                self._state = _WAITING_FOR_PRED
+            elif next_token == ".":
+                yield self._current_triple()
+                self._state = _WAITING_FOR_SUBJ
+            else:
+                self._assing_tmp_element_and_promote_state(next_token)
+            next_token, next_index = self._next_line_token(a_line, next_index)
+
+    def _current_triple(self):
+        return self._tmp_s, self._tmp_p, self._tmp_o
+
+    def _assing_tmp_element_and_promote_state(self, token):
+        if self._state == _WAITING_FOR_SUBJ:
+            self._tmp_s = self._parse_elem(token)
+            self._state = _WAITING_FOR_PRED
+        elif self._state == _WAITING_FOR_PRED:
+            self._tmp_p = self._parse_elem(token)
+            self._state = _WAITING_FOR_OBJ
+        elif self._state == _WAITING_FOR_OBJ:
+            self._tmp_o = self._parse_elem(token)
+            self._state = _NOT_WAITING
+        else:
+            raise ValueError("Malformed file. Processing an unexpected token: " + token)
 
 
+    def _next_line_token(self, a_line, start_index):
+        while(start_index < len(a_line) and a_line[start_index] == " "):
+            start_index += 1
+        if start_index >= len(a_line):
+            return None, None
+        if a_line[start_index] in _CLOSURES:
+            return a_line[start_index], start_index + 1
+        elif a_line[start_index] == "<":
+            end_index = a_line.find(">", start_index)
+            return self._parse_cornered_element(cornered_element=a_line[start_index:end_index+1]), end_index + 1
+        elif a_line[start_index] == '"':
+            end_index = self._find_next_quoted_literal_ending(a_line, start_index)
+            return a_line[start_index:end_index+1], end_index + 1
+        else:  # could be a prefixed element, a bnode, a non-string literal... find the next blank anyway
+            end_index = self._find_next_blank(a_line, start_index)
+            return a_line[start_index:end_index], end_index + 1
+
+
+    def _find_next_blank(self, target_str, start_index):
+        pos = target_str.find(" ", start_index)
+        return len(target_str)-1 if pos == -1 else pos
+
+
+    def _find_next_unescaped_quotes(self, target_str, start_index):
+        pos = target_str.find('"', start_index)
+        while pos != -1:
+            if target_str[pos-1] != "\\":
+                return pos  # not escaped
+            if pos >= 2 and target_str[pos-2] == '\\':
+                return pos  # the scape is scaped, so not escaped
+        if pos == -1:
+            raise ValueError("Is this line malformed? Can`t find quotes matching: " + target_str)
+
+    def _find_next_quoted_literal_ending(self, target_str, start_index):
+        next_quotes = self._find_next_unescaped_quotes(target_str=target_str,
+                                                       start_index=start_index+1)
+        if next_quotes +1 > len(target_str) or target_str[next_quotes + 1] == " ":
+            return next_quotes
+        elif target_str[next_quotes + 1] == "^":
+            return self._find_next_blank(target_str, next_quotes) -1
+        else:
+            raise ValueError("Malformed literal? It seems like there si a problem of unmatching quotes: " + target_str)
 
     def _process_line(self, str_line):
         str_line = self._clean_line(str_line)
@@ -233,6 +342,8 @@ class BigTtlTriplesYielder(BaseTriplesYielder):
             return self._parse_cornered_element(raw_elem)
         elif raw_elem in _RDF_TYPE_CONTRACTED:
             return _RDF_TYPE_URI
+        elif raw_elem.startswith('"'):  # it's a literal, will be better parsed later
+            return raw_elem
         elif ":" in raw_elem:
             if raw_elem.startswith("_:"):
                 return raw_elem
@@ -264,9 +375,10 @@ class BigTtlTriplesYielder(BaseTriplesYielder):
     def ignored_triples(self):
         return self._ignored_triples
 
-    def _reset_count(self):
+    def _reset_parsing(self):
         self._error_triples = 0
         self._triples_count = 0
         self._ignored_triples = 0
+        self._state = _WAITING_FOR_SUBJ
 
 
