@@ -1,6 +1,8 @@
 from SPARQLWrapper import SPARQLWrapper, JSON
 from urllib.error import HTTPError
 from time import sleep
+import ssl
+ssl._create_default_https_context = ssl._create_unverified_context
 
 from SPARQLWrapper.SPARQLExceptions import EndPointInternalError
 
