@@ -25,7 +25,8 @@ def get_class_profiler(target_classes_dict, source_file, list_of_source_files, i
                        built_shape_map=None,
                        remove_empty_shapes=True,
                        limit_remote_instances=-1,
-                       inverse_paths=False):
+                       inverse_paths=False,
+                       all_classes_mode=False):
     yielder = get_triple_yielder(source_file=source_file,
                                  list_of_source_files=list_of_source_files,
                                  input_format=input_format,
@@ -48,7 +49,8 @@ def get_class_profiler(target_classes_dict, source_file, list_of_source_files, i
                                  built_remote_graph=built_remote_graph,
                                  built_shape_map=built_shape_map,
                                  limit_remote_instances=limit_remote_instances,
-                                 inverse_paths=inverse_paths)
+                                 inverse_paths=inverse_paths,
+                                 all_classes_mode=all_classes_mode)
 
     return ClassProfiler(triples_yielder=yielder,
                          instances_dict=target_classes_dict,
