@@ -5,10 +5,11 @@ from shexer.consts import NT, RDF_TYPE
 from shexer.shaper import Shaper
 from shexer.utils.uri import remove_corners
 import json
+import sys
 
 ################ CONFIG
 
-PORT = 8080
+# PORT = 8080
 HOST = "0.0.0.0"
 MAX_LEN = 100000
 
@@ -390,7 +391,8 @@ def _call_shaper(target_classes, graph, input_fotmat, instantiation_prop,
                     depth_for_building_subgraph=query_depth,
                     disable_comments=disable_comments,
                     namespaces_for_qualifier_props=namespaces_for_qualifier_props,
-                    shape_qualifiers_mode=shape_qualifiers_mode
+                    shape_qualifiers_mode=shape_qualifiers_mode,
+                    wikidata_annotation=True
                     )
     result = shaper.shex_graph(acceptance_threshold=threshold, string_output=True)
     return _jsonize_response(result)
@@ -507,6 +509,10 @@ def shexer():
         error_pool.append("Internal unexpected server error: " + str(e))
         return _return_json_error_pool(error_pool)
 
-CORS(app)
+def run():
+    port = 80 if len(sys.argv) < 2 else int(sys.argv[1])
+    CORS(app)
+    app.run(port=port, host=HOST, ssl_context='adhoc')
+
 if __name__ == "__main__":
-    app.run(port=PORT, host=HOST)
\ No newline at end of file
+    run()
